/*
 * @(#)ValueHolder.java	1.0 96/05/01 Eric Lunt
 *
 * Copyright (C) 1996 by Eric Lunt <elunt@mcs.net>.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

package com.bdnm.mvc;

/**
 * This class represents a holder on an Object.
 * It implements the Valuable interface, so you
 * can set and get this value.  In addition, it
 * is an Observable so you can share this instance
 * between any number of Observers.  The argument
 * that is sent in an update is the new value.
 *
 * @version 1.0 05/01/96
 * @author Eric Lunt
 */
public class ValueHolder extends ValueModel {
    /**
     * Holds onto the actual value.
     */
    private Object value;

    /**
     * Construct an instance with an initial value.
     * @param   initValue   the initial value
     */
    public ValueHolder(Object initValue) {
        super();
        value = initValue;
    }

    /**
     * Called to get the current value this object represents.
     * Necessary to implement Valuable.
     * @return the current value, which is cast to an Object
     */
    public Object getValue() {
        return value;
    }

    /**
     * Called to set the current value, which must
     * be cast to an Object. This will also notify all
     * Observers of the change. Necessary to implement
     * Valuable.
     *
     * @param   newValue    the new value to set
     */
    public synchronized void setValue(Object newValue) {
        if (newValue != value) {
            value = newValue;
            setChanged();
            notifyObservers(value);
        }
    }

}